Class: Google::Apis::VpcaccessV1beta1::Location
- Inherits:
-
Object
- Object
- Google::Apis::VpcaccessV1beta1::Location
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vpcaccess_v1beta1/classes.rb,
lib/google/apis/vpcaccess_v1beta1/representations.rb,
lib/google/apis/vpcaccess_v1beta1/representations.rb
Overview
A resource that represents a Google Cloud location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The friendly name for this location, typically a nearby city name.
-
#labels ⇒ Hash<String,String>
Cross-service attributes for the location.
-
#location_id ⇒ String
The canonical id for this location.
-
#metadata ⇒ Hash<String,Object>
Service-specific metadata.
-
#name ⇒ String
Resource name for the location, which may vary between implementations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Location
constructor
A new instance of Location.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Location
Returns a new instance of Location.
244 245 246 |
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The friendly name for this location, typically a nearby city name. For example,
"Tokyo".
Corresponds to the JSON property displayName
219 220 221 |
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 219 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Cross-service attributes for the location. For example "cloud.googleapis.com/
region": "us-east1"
Corresponds to the JSON property labels
225 226 227 |
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 225 def labels @labels end |
#location_id ⇒ String
The canonical id for this location. For example: "us-east1".
Corresponds to the JSON property locationId
230 231 232 |
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 230 def location_id @location_id end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata. For example the available capacity at the given
location.
Corresponds to the JSON property metadata
236 237 238 |
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 236 def @metadata end |
#name ⇒ String
Resource name for the location, which may vary between implementations. For
example: "projects/example-project/locations/us-east1"
Corresponds to the JSON property name
242 243 244 |
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 242 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
249 250 251 252 253 254 255 |
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 249 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location_id = args[:location_id] if args.key?(:location_id) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |