Class: Google::Apis::VpcaccessV1beta1::Subnet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vpcaccess_v1beta1/classes.rb,
lib/google/apis/vpcaccess_v1beta1/representations.rb,
lib/google/apis/vpcaccess_v1beta1/representations.rb

Overview

The subnet in which to house the connector

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subnet

Returns a new instance of Subnet.



494
495
496
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Optional. Subnet name (relative, not fully qualified). E.g. if the full subnet selfLink is https://compute.googleapis.com/compute/v1/projects/`project`/ regions/region/subnetworks/subnetName the correct input for this field would be subnetName Corresponds to the JSON property name

Returns:

  • (String)


486
487
488
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 486

def name
  @name
end

#project_idString

Optional. Project in which the subnet exists. If not set, this project is assumed to be the project for which the connector create request was issued. Corresponds to the JSON property projectId

Returns:

  • (String)


492
493
494
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 492

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



499
500
501
502
# File 'lib/google/apis/vpcaccess_v1beta1/classes.rb', line 499

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
end